HEADER = "[SC] "

CONNECTION_CLOSED = f"{HEADER}Connection closed."
NO_CLIENT = f"{HEADER}No client connections."
NO_DATA = f"{HEADER}No data was provided to send."
SENT = f"{HEADER}Sent."
SERVER_STARTED = f"{HEADER}Server started."
TIMEOUT_RECEIVED = f"{HEADER}Send / Receive timed out."

